# flake8: noqa

"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from MergeHRISClient.api_client import ApiClient

# import Configuration
from MergeHRISClient.configuration import Configuration

# import exceptions
from MergeHRISClient.exceptions import OpenApiException
from MergeHRISClient.exceptions import ApiAttributeError
from MergeHRISClient.exceptions import ApiTypeError
from MergeHRISClient.exceptions import ApiValueError
from MergeHRISClient.exceptions import ApiKeyError
from MergeHRISClient.exceptions import ApiException
