"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest
from unittest.mock import MagicMock

import MergeHRISClient
from MergeHRISClient.model.pay_frequency_enum import PayFrequencyEnum
from MergeHRISClient.api_client import ApiClient


class TestPayFrequencyEnum(unittest.TestCase):
    """PayFrequencyEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPayFrequencyEnum(self):
        """Test PayFrequencyEnum"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PayFrequencyEnum()  # noqa: E501

        # no tests for enums
        pass

if __name__ == '__main__':
    unittest.main()
