"""
    Merge HRIS API

    The unified API for building rich integrations with multiple HR Information System platforms.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: hello@merge.dev
    Generated by: https://openapi-generator.tech
"""


import unittest

import MergeHRISClient
from MergeHRISClient.api.regenerate_key_api import RegenerateKeyApi  # noqa: E501


class TestRegenerateKeyApi(unittest.TestCase):
    """RegenerateKeyApi unit test stubs"""

    def setUp(self):
        self.api = RegenerateKeyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_regenerate_key_create(self):
        """Test case for regenerate_key_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
